@@ -1,4 +1,3 @@
-
 from textual.app import ComposeResult
 from textual.screen import Screen
 from textual.widgets import Static
@@ -18,7 +17,4 @@ class HelpScreen(Screen):
             keys, _, description = binding
             help_text += f"{keys:<12} - {description}\n"
         yield Static(help_text)
-        yield Static(
-            "[bold]Press 'q' to close this help.[/bold]", id="help-footer"
-        )
-
+        yield Static("[bold]Press 'q' to close this help.[/bold]", id="help-footer")
